diff --git a/util/strings.php b/util/strings.php
index 6e6c4b27c..f42449690 100644
--- a/util/strings.php
+++ b/util/strings.php
@@ -4,7 +4,6 @@ $a->strings['Page not found.' ] = 'Page not found.' ;
$a->strings['Permission denied'] = 'Permission denied';
$a->strings['Permission denied.'] = 'Permission denied.';
$a->strings['Nickname or Email address: '] = 'Nickname or Email address: ';
-$a->strings['Welcome to '] = 'Welcome to ';
$a->strings['Password: '] = 'Password: ';
$a->strings['Login'] = 'Login';
$a->strings['Nickname/Email/OpenID: '] = 'Nickname/Email/OpenID: ';
@@ -84,6 +83,7 @@ $a->strings['Remote site reported: '] = 'Remote site reported: ';
$a->strings["Temporary failure. Please wait and try again."] = "Temporary failure. Please wait and try again.";
$a->strings["Introduction failed or was revoked."] = "Introduction failed or was revoked.";
$a->strings['Unable to set contact photo.'] = 'Unable to set contact photo.';
+$a->strings['is now friends with'] = 'is now friends with';
$a->strings['No user record found for '] = 'No user record found for ';
$a->strings['Our site encryption key is apparently messed up.'] = 'Our site encryption key is apparently messed up.';
$a->strings['Empty site URL was provided or URL could not be decrypted by us.'] = 'Empty site URL was provided or URL could not be decrypted by us.';
@@ -108,6 +108,9 @@ $a->strings["not found at the given location."] = "not found at the given locati
$a->strings["Introduction complete."] = "Introduction complete.";
$a->strings['Unrecoverable protocol error.'] = 'Unrecoverable protocol error.';
$a->strings['Profile unavailable.'] = 'Profile unavailable.';
+$a->strings[' has received too many connection requests today.'] = ' has received too many connection requests today.';
+$a->strings['Spam protection measures have been invoked.'] = 'Spam protection measures have been invoked.';
+$a->strings['Friends are advised to please try again in 24 hours.'] = 'Friends are advised to please try again in 24 hours.';
$a->strings["Invalid locator"] = "Invalid locator";
$a->strings["Unable to resolve your name at the provided location."] = "Unable to resolve your name at the provided location.";
$a->strings['You have already introduced yourself here.'] = 'You have already introduced yourself here.';
@@ -149,11 +152,12 @@ $a->strings['Membership list updated.'] = 'Membership list updated.';
$a->strings['Group removed.'] = 'Group removed.';
$a->strings['Unable to remove group.'] = 'Unable to remove group.';
$a->strings['Delete'] = 'Delete';
+$a->strings["Welcome to "] = "Welcome to ";
$a->strings['Could not create/connect to database.'] = 'Could not create/connect to database.';
$a->strings['Connected to database.'] = 'Connected to database.';
$a->strings['Database import succeeded.'] = 'Database import succeeded.';
$a->strings['IMPORTANT: You will need to [manually] setup a scheduled task for the poller.'] = 'IMPORTANT: You will need to [manually] setup a scheduled task for the poller.';
-$a->strings['Please see the file INSTALL.'] = 'Please see the file INSTALL.';
+$a->strings['Please see the file "INSTALL.txt".'] = 'Please see the file "INSTALL.txt".';
$a->strings['Database import failed.'] = 'Database import failed.';
$a->strings['You may need to import the file "database.sql" manually using phpmyadmin or mysql.'] = 'You may need to import the file "database.sql" manually using phpmyadmin or mysql.';
$a->strings['Welcome to Friendika.'] = 'Welcome to Friendika.';
@@ -163,16 +167,16 @@ $a->strings['This is required. Please adjust the configuration file .htconfig.ph
$a->strings['The command line version of PHP on your system does not have "register_argc_argv" enabled.'] = 'The command line version of PHP on your system does not have "register_argc_argv" enabled.';
$a->strings['This is required for message delivery to work.'] = 'This is required for message delivery to work.';
$a->strings['Error: the "openssl_pkey_new" function on this system is not able to generate encryption keys'] = 'Error: the "openssl_pkey_new" function on this system is not able to generate encryption keys';
+$a->strings['If running under Windows, please see "http://www.php.net/manual/en/openssl.installation.php".'] = 'If running under Windows, please see "http://www.php.net/manual/en/openssl.installation.php".';
$a->strings['Error: Apache webserver mod-rewrite module is required but not installed.'] = 'Error: Apache webserver mod-rewrite module is required but not installed.';
$a->strings['Error: libCURL PHP module required but not installed.'] = 'Error: libCURL PHP module required but not installed.';
$a->strings['Error: GD graphics PHP module with JPEG support required but not installed.'] = 'Error: GD graphics PHP module with JPEG support required but not installed.';
$a->strings['Error: openssl PHP module required but not installed.'] = 'Error: openssl PHP module required but not installed.';
$a->strings['Error: mysqli PHP module required but not installed.'] = 'Error: mysqli PHP module required but not installed.';
-$a->strings['Please see the file "INSTALL".'] = 'Please see the file "INSTALL".';
$a->strings['The web installer needs to be able to create a file called ".htconfig.php" in the top folder of your web server and it is unable to do so.'] = 'The web installer needs to be able to create a file called ".htconfig.php" in the top folder of your web server and it is unable to do so.';
$a->strings['This is most often a permission setting, as the web server may not be able to write files in your folder - even if you can.'] = 'This is most often a permission setting, as the web server may not be able to write files in your folder - even if you can.';
$a->strings['Please check with your site documentation or support people to see if this situation can be corrected.'] = 'Please check with your site documentation or support people to see if this situation can be corrected.';
-$a->strings['If not, you may be required to perform a manual installation. Please see the file "INSTALL" for instructions.'] = 'If not, you may be required to perform a manual installation. Please see the file "INSTALL" for instructions.';
+$a->strings['If not, you may be required to perform a manual installation. Please see the file "INSTALL.txt" for instructions.'] = 'If not, you may be required to perform a manual installation. Please see the file "INSTALL.txt" for instructions.';
$a->strings['The database configuration file ".htconfig.php" could not be written. Please use the enclosed text to create a configuration file in your web server root.'] = 'The database configuration file ".htconfig.php" could not be written. Please use the enclosed text to create a configuration file in your web server root.';
$a->strings['Errors encountered creating database tables.'] = 'Errors encountered creating database tables.';
$a->strings[' : '] = ' : ';
@@ -305,6 +309,7 @@ $a->strings['Your registration is pending approval by the site owner.'] = 'Your
$a->strings["You may \x28optionally\x29 fill in this form via OpenID by supplying your OpenID and clicking 'Register'."] = "You may \x28optionally\x29 fill in this form via OpenID by supplying your OpenID and clicking 'Register'.";
$a->strings['If you are not familiar with OpenID, please leave that field blank and fill in the rest of the items.'] = 'If you are not familiar with OpenID, please leave that field blank and fill in the rest of the items.';
$a->strings["Your OpenID \x28optional\x29: "] = "Your OpenID \x28optional\x29: ";
+$a->strings['Shared content is covered by the Creative Commons Attribution 3.0 license.'] = 'Shared content is covered by the Creative Commons Attribution 3.0 license.';
$a->strings['Registration'] = 'Registration';
$a->strings['Your Full Name ' . "\x28" . 'e.g. Joe Smith' . "\x29" . ': '] = 'Your Full Name ' . "\x28" . 'e.g. Joe Smith' . "\x29" . ': ';
$a->strings['Your Email Address: '] = 'Your Email Address: ';
@@ -323,6 +328,8 @@ $a->strings[' Please use a shorter name.'] = ' Please use a shorter name.';
$a->strings[' Name too short.'] = ' Name too short.';
$a->strings[' Not valid email.'] = ' Not valid email.';
$a->strings['Settings updated.'] = 'Settings updated.';
+$a->strings['Plugin Settings'] = 'Plugin Settings';
+$a->strings['Account Settings'] = 'Account Settings';
$a->strings['OpenID: '] = 'OpenID: ';
$a->strings[" \x28Optional\x29 Allow this OpenID to login to this account."] = " \x28Optional\x29 Allow this OpenID to login to this account.";
$a->strings['Profile is not published.'] = 'Profile is not published.';
diff --git a/view/en/settings.tpl b/view/en/settings.tpl
index 594ce73fc..5e1bfabf4 100644
--- a/view/en/settings.tpl
+++ b/view/en/settings.tpl
@@ -1,5 +1,7 @@
+
+
$nickname_block
diff --git a/view/it/strings.php b/view/it/strings.php
index 08eb5063c..3640997d9 100644
--- a/view/it/strings.php
+++ b/view/it/strings.php
@@ -153,7 +153,7 @@ $a->strings['Could not create/connect to database.'] = 'Impossibile creare/colle
$a->strings['Connected to database.'] = 'Collegato al database.';
$a->strings['Database import succeeded.'] = 'Importazione database completata.';
$a->strings['IMPORTANT: You will need to [manually] setup a scheduled task for the poller.'] = 'IMPORTANTE: Devi impostare manualmente un operazione pianificata per il poller';
-$a->strings['Please see the file INSTALL.'] = 'Guarda il file INSTALL.';
+$a->strings['Please see the file "INSTALL.txt".'] = 'Guarda il file "INSTALL.txt".';
$a->strings['Database import failed.'] = 'Importazione database fallita.';
$a->strings['You may need to import the file "database.sql" manually using phpmyadmin or mysql.'] = 'Potresti dover importare il file "database.sql" manualmente con phpmyadmin o mysql';
$a->strings['Welcome to Friendika.'] = 'Benvenuto su Friendika.';
@@ -168,11 +168,11 @@ $a->strings['Error: libCURL PHP module required but not installed.'] = 'Errore:
$a->strings['Error: GD graphics PHP module with JPEG support required but not installed.'] = 'Errore: Il modulo GD graphics di PHP con supporto a JPEG è richiesto ma non installato.';
$a->strings['Error: openssl PHP module required but not installed.'] = 'Errore: il modulo openssl di PHP è richiesto ma non installato.';
$a->strings['Error: mysqli PHP module required but not installed.'] = 'Errore: il modulo mysqli di PHP è richiesto ma non installato';
-$a->strings['Please see the file "INSTALL".'] = 'Guarda il file "INSTALL".';
+$a->strings['Please see the file "INSTALL.txt".'] = 'Guarda il file "INSTALL.txt".';
$a->strings['The web installer needs to be able to create a file called ".htconfig.php" in the top folder of your web server and it is unable to do so.'] = 'L\'installazione web deve poter creare un file chiamato ".htconfig.php" nella cartella principale del tuo web server ma non è in grado di farlo.';
$a->strings['This is most often a permission setting, as the web server may not be able to write files in your folder - even if you can.'] = 'Ció è dovuto spesso a impostazioni di permessi, dato che il web server puo\' scrivere il file nella tua cartella, anche se tu puoi.';
$a->strings['Please check with your site documentation or support people to see if this situation can be corrected.'] = 'Controlla la documentazione del tuo sito o con il personale di suporto se la situazione puo\' essere corretta.';
-$a->strings['If not, you may be required to perform a manual installation. Please see the file "INSTALL" for instructions.'] = 'Altrimenti dovrai procedere con l\'installazione manuale. Guarda il file "INSTALL" per istuzioni';
+$a->strings['If not, you may be required to perform a manual installation. Please see the file "INSTALL.txt" for instructions.'] = 'Altrimenti dovrai procedere con l\'installazione manuale. Guarda il file "INSTALL.txt" per istuzioni';
$a->strings['The database configuration file ".htconfig.php" could not be written. Please use the enclosed text to create a configuration file in your web server root.'] = 'Il file di configurazione del database ".htconfig.php" non puo\' essere scritto. Usa il testo qui di seguito per creare un file di configurazione nella cartella principale del tuo sito.';
$a->strings['Errors encountered creating database tables.'] = 'Errori creando le tabelle nel database.';
$a->strings[' : '] = ' : ';
@@ -305,6 +305,7 @@ $a->strings['Your registration is pending approval by the site owner.'] = 'La tu
$a->strings["You may \x28optionally\x29 fill in this form via OpenID by supplying your OpenID and clicking 'Register'."] = "Puoi \x28opzionalmento\x29 riempire questa maschera via OpenID inserendo il tuo OpenID e cliccando 'Registra'.";
$a->strings['If you are not familiar with OpenID, please leave that field blank and fill in the rest of the items.'] = 'Se non hai famigliarità con OpenID, lascia quel campo in bianco e riempi il resto della maschera.';
$a->strings["Your OpenID \x28optional\x29: "] = "Il tuo OpenID \x28opzionale\x29: ";
+$a->strings['Shared content is covered by the Creative Commons Attribution 3.0 license.'] = 'Contenuto in comune h coperto da licenza Creative Commons Attribution 3.0.';
$a->strings['Registration'] = 'Registrazione';
$a->strings['Your Full Name ' . "\x28" . 'e.g. Joe Smith' . "\x29" . ': '] = 'Il tuo Nome Completo ' . "\x28" . 'p.e. Mario Rossi' . "\x29" . ': ';
$a->strings['Your Email Address: '] = 'Il tuo Indirizzo Email: ';
@@ -323,6 +324,8 @@ $a->strings[' Please use a shorter name.'] = ' Usa un nome più corto.';
$a->strings[' Name too short.'] = ' Nome troppo corto.';
$a->strings[' Not valid email.'] = ' Email non valida.';
$a->strings['Settings updated.'] = 'Impostazioni aggiornate.';
+$a->strings['Plugin Settings'] = 'Impostazioni Plugin';
+$a->strings['Account Settings'= = 'Impostazioni Account';
$a->strings['OpenID: '] = 'OpenID: ';
$a->strings[" \x28Optional\x29 Allow this OpenID to login to this account."] = " \x28Opzionale\x29 Permetti a questo OpenID di accedere a questo account.";
$a->strings['Profile is not published.'] = 'Il profilo non è pubblicato.';
diff --git a/view/register.tpl b/view/register.tpl
index 08da5112d..ed528bb33 100644
--- a/view/register.tpl
+++ b/view/register.tpl
@@ -44,3 +44,6 @@
+
+
$license
+
diff --git a/view/theme/default/style.css b/view/theme/default/style.css
index e3cddc355..240ace896 100644
--- a/view/theme/default/style.css
+++ b/view/theme/default/style.css
@@ -1946,4 +1946,14 @@ a.mail-list-link {
.clear {
clear: both;
-}
\ No newline at end of file
+}
+
+.cc-license {
+ margin-top: 50px;
+ font-size: 70%;
+}
+
+
+#plugin-settings-link, #account-settings-link {
+ margin-bottom: 25px;
+}
diff --git a/addon/randplace/randplace.php b/addon/randplace/randplace.php
index e14ae74c7..2e1bd33ac 100644
--- a/addon/randplace/randplace.php
+++ b/addon/randplace/randplace.php
@@ -36,13 +36,13 @@ function randplace_install() {
/**
*
* Then we'll attach into the settings page, on both the
* form and post hooks so that we can create and update
* user preferences.
*
*/
- register_hook('settings_form', 'addon/randplace/randplace.php', 'randplace_settings');
+ register_hook('plugin_settings', 'addon/randplace/randplace.php', 'randplace_settings');
register_hook('settings_post', 'addon/randplace/randplace.php', 'randplace_settings_post');
logger("installed randplace");
@@ -60,7 +60,7 @@ function randplace_uninstall() {
*/
unregister_hook('post_local', 'addon/randplace/randplace.php', 'randplace_post_hook');
- unregister_hook('settings_form', 'addon/randplace/randplace.php', 'randplace_settings');
+ unregister_hook('plugin_settings', 'addon/randplace/randplace.php', 'randplace_settings');
unregister_hook('settings_post', 'addon/randplace/randplace.php', 'randplace_settings_post');
@@ -142,7 +142,8 @@ function randplace_settings_post($a,$post) {
/**
* Called from the end of the settings form.
* Add our own settings info to the page.
*
*/
@@ -154,7 +155,7 @@ function randplace_settings(&$a,&$s) {
if(! local_user())
return;
- /* Add our stylesheet so we can match the page layout */
+ /* Add our stylesheet to the page so we can make our settings look nice */
$a->page['htmlhead'] .= '' . "\r\n";
@@ -164,7 +165,7 @@ function randplace_settings(&$a,&$s) {
$checked = (($enabled) ? ' checked="checked" ' : '');
- /* Add some HTML to the form */
+ /* Add some HTML to the existing form */
$s .= '
';
+
+ $o .= '';
+ return $o;
+ }
+
require_once('include/acl_selectors.php');
$p = q("SELECT * FROM `profile` WHERE `is-default` = 1 AND `uid` = %d LIMIT 1",
@@ -36,13 +36,13 @@ function randplace_install() {
/**
*
- * Then we'll attach into the settings page, on both the
- * form and post hooks so that we can create and update
+ * Then we'll attach into the plugin settings page, and also the
+ * settings post hook so that we can create and update
* user preferences.
*
@@ -142,7 +142,8 @@ function randplace_settings_post($a,$post) {
/**
- * Called from the end of the settings form.
+ *
+ * Called from the Plugin Setting form.
* Add our own settings info to the page.
*